summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMike Lockwood <lockwood@android.com>2009-06-19 14:57:20 -0400
committerMike Lockwood <lockwood@android.com>2009-06-19 14:57:20 -0400
commit205021cd79eb84b4931ed79fd6d995aa8ca8c29e (patch)
tree6545cc6011e2e6b320c15e2cc67605ca1bb5553e
parent4403519ac60f99bf0100a7d6eed79b09bd9e5be7 (diff)
downloadplatform_hardware_libhardware_legacy-205021cd79eb84b4931ed79fd6d995aa8ca8c29e.tar.gz
platform_hardware_libhardware_legacy-205021cd79eb84b4931ed79fd6d995aa8ca8c29e.tar.bz2
platform_hardware_libhardware_legacy-205021cd79eb84b4931ed79fd6d995aa8ca8c29e.zip
gps: Set SUPL server via hostname rather than IP address.
The GPS engine needs the hostname for the secure SUPL case and deferring the DNS lookup to the HAL might be helpful in the future if the SUPL server is on a carrier's private network. Signed-off-by: Mike Lockwood <lockwood@android.com>
-rwxr-xr-x[-rw-r--r--]include/hardware_legacy/gps.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/hardware_legacy/gps.h b/include/hardware_legacy/gps.h
index 62b3ee0..dd3e606 100644..100755
--- a/include/hardware_legacy/gps.h
+++ b/include/hardware_legacy/gps.h
@@ -300,9 +300,9 @@ typedef struct {
*/
int (*data_conn_failed)();
/**
* Sets the IP address and port for the AGPS server.
*/
- int (*set_server)(AGpsType type, uint32_t addr, int port );
+ int (*set_server)( AGpsType type, const char* hostname, int port );
} AGpsInterface;
/** Returns the hardware GPS interface. */
@@ -300,9 +300,9 @@ typedef struct {
int (*data_conn_failed)();
/**
- * Sets the IP address and port for the AGPS server.
+ * Sets the hostname and port for the AGPS server.
*/